@@ -1,5 +1,5 @@
 package vCard::Role::FileIO;
-$vCard::Role::FileIO::VERSION = '3.04';
+$vCard::Role::FileIO::VERSION = '3.05';
 use Moo::Role;
 use Path::Tiny;
 
@@ -12,13 +12,13 @@ requires qw/encoding_in encoding_out/;
 
 sub _iomode_out {
     my ($self) = @_;
-    return {} if $self->encoding_out eq 'none';
+    return { binmode => ':raw' } if $self->encoding_out eq 'none';
     return { binmode => ':raw:encoding(' . $self->encoding_out . ')' };
 }
 
 sub _iomode_in {
     my ($self) = @_;
-    return {} if $self->encoding_in eq 'none';
+    return { binmode => ':raw' } if $self->encoding_in eq 'none';
     return { binmode => ':raw:encoding(' . $self->encoding_in . ')' };
 }
 
